@@ -1,13 +1,10 @@
-use strictures 1;
-use diagnostics;
+use strict;
+use warnings;
 package Data::Skeleton;
-{
-  $Data::Skeleton::VERSION = '0.03';
-}
+$Data::Skeleton::VERSION = '0.04';
 use Moo;
 use MooX::Types::MooseLike::Base qw/Str HashRef Bool/;
 use Scalar::Util qw(blessed);
-use Data::Dumper::Concise;
 
 =head1 NAME
 
@@ -98,7 +95,11 @@ sub deflesh {
     } elsif (blessed($data) && eval { keys %{$data}; 1; } ) {
         return $self->_blank_hash($data);
     } else {
-        die "You need to pass the deflesh method either a hash or an array reference";
+        die "You must pass the deflesh method one of:
+    HashRef
+    ArrayRef
+    Object that is a blessed HashRef
+";
     }
 }
 
@@ -197,20 +198,6 @@ sub _blank_array {
 
 1;
 
-=head1 SEE ALSO
-
-Data::Dump::Partial is way more feature rich than this module.
-The only reason I didn't use it is that the output is all on one line.
-To get something similar to deflesh with Data::Dump::Partial do:
-
-    say Dumper dump_partial($data, {max_total_len => $big_enough_number, max_len => 0});
-
-The important part being max_len = 0
-
-This module was inspired when I wanted to see the "schema" of a MongoDB document.
-If you want to enforce a schema (and have a place to recall its nature)
-then you might consider L<Data::Schema>
-
 =head1 AUTHORS
 
 Mateu Hunter C<hunter@missoula.org>
